==> qtjambi-networkauth-5.15.7-sources.jar: io/qt/network/auth/QOAuthOobReplyHandler.java <==
package io.qt.network.auth;


/**
 * <p>Java wrapper for Qt class QOAuthOobReplyHandler</p>
 */
public class QOAuthOobReplyHandler extends io.qt.network.auth.QAbstractOAuthReplyHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QOAuthOobReplyHandler.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QOAuthOobReplyHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOAuthOobReplyHandler() {
        this((io.qt.core.QObject)null);
    }
    
    public QOAuthOobReplyHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QOAuthOobReplyHandler instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public java.lang.String callback(){
        return callback_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String callback_native_constfct(long __this__nativeId);
    
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public void networkReplyFinished(io.qt.network.QNetworkReply reply){
        networkReplyFinished_native_QNetworkReply_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reply));
    }
    
    @io.qt.QtUninvokable
    private native void networkReplyFinished_native_QNetworkReply_ptr(long __this__nativeId, long reply);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QOAuthOobReplyHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QOAuthOobReplyHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QOAuthOobReplyHandler instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-networkauth-5.15.14-sources.jar: io/qt/network/auth/QOAuthOobReplyHandler.java <==
package io.qt.network.auth;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QOAuthOobReplyHandler</p>
 */
public class QOAuthOobReplyHandler extends io.qt.network.auth.QAbstractOAuthReplyHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QOAuthOobReplyHandler.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QOAuthOobReplyHandler() {
        this((io.qt.core.QObject)null);
    }
    
    public QOAuthOobReplyHandler(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QOAuthOobReplyHandler instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    public java.lang.@NonNull String callback(){
        return callback_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String callback_native_constfct(long __this__nativeId);
    
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public void networkReplyFinished(io.qt.network.@Nullable QNetworkReply reply){
        networkReplyFinished_native_QNetworkReply_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reply));
    }
    
    @QtUninvokable
    private native void networkReplyFinished_native_QNetworkReply_ptr(long __this__nativeId, long reply);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QOAuthOobReplyHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QOAuthOobReplyHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QOAuthOobReplyHandler instance, QDeclarativeConstructor constructor);
    
}
